@@ -63,7 +63,7 @@ emm_basis.multinom = function(object, trms, xlev, grid,
 }
 
 # post-processing of ref_grid for "prob" mode
-.multinom.postGrid = function(object) {
+.multinom.postGrid = function(object, ...) {
     linfct = object@linfct
     misc = object@misc
     # grid will have multresp as slowest-varying factor...
