@@ -1,5 +1,5 @@
 ##############################################################################
-#    Copyright (c) 2012-2017 Russell V. Lenth                                #
+#    Copyright (c) 2012-2019 Russell V. Lenth                                #
 #                                                                            #
 #    This file is part of the emmeans package for R (*emmeans*)              #
 #                                                                            #
@@ -282,14 +282,14 @@
 #'   \code{\link{emmeans}}. Supported models are detailed in
 #'   \href{../doc/models.html}{\code{vignette("models", "emmeans")}}.
 #'   
-#' @note The system default for \code{cov.nest} causes models
+#' @note The system default for \code{cov.keep} causes models
 #'   containing indicator variables to be handled differently than in
 #'   \pkg{emmeans} version 1.4.1 or earlier. To replicate older
 #'   analyses, change the default via 
-#'   \samp{emm_options(cov.nest = character(0))}.
+#'   \samp{emm_options(cov.keep = character(0))}.
 #'   
 #' @note Some earlier versions of \pkg{emmeans} offer a \code{covnest} argument.
-#'   This is now obsolete; if \code{cov.nest} is specified, it is harmlessly
+#'   This is now obsolete; if \code{covnest} is specified, it is harmlessly
 #'   ignored. Cases where it was needed are now handled appropriately via the
 #'   code associated with \code{cov.keep}.
 #'
@@ -741,7 +741,7 @@ ref_grid <- function(object, at, cov.reduce = mean, cov.keep = get_emm_option("c
         if (is.character(hook))
             hook = get(hook)
         result@misc$postGridHook = NULL
-        result = hook(result)
+        result = hook(result, ...)
     }
     if(transform != "none")
         result = regrid(result, transform = transform, sigma = sigma, ...)
